@@ -12,7 +12,7 @@
 <par>This module contains entities for many abbreviations and acronyms.</par>
 """
 
-__version__ = tuple(map(int, "$Revision: 2.42 $"[11:-2].split(".")))
+__version__ = tuple(map(int, "$Revision: 2.43 $"[11:-2].split(".")))
 # $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/abbr.py,v $
 
 from ll.xist import xsc
@@ -450,6 +450,12 @@ class utc(base):
 	lang = u"en"
 
 
+class wsgi(base):
+	content = u"WSGI"
+	title = u"Web Server Gateway Interface"
+	lang = u"en"
+
+
 class __ns__(xsc.Namespace):
 	xmlname = "abbr"
 	xmlurl = "http://xmlns.livinglogic.de/xist/ns/abbr"
