@@ -1,14 +1,14 @@
 #! /usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 
-## Copyright 1999-2004 by LivingLogic AG, Bayreuth, Germany.
-## Copyright 1999-2004 by Walter Drwald
+## Copyright 1999-2005 by LivingLogic AG, Bayreuth/Germany.
+## Copyright 1999-2005 by Walter Drwald
 ##
 ## All Rights Reserved
 ##
 ## See xist/__init__.py for the license
 
-__version__ = tuple(map(int, "$Revision: 2.118 $"[11:-2].split(".")))
+__version__ = tuple(map(int, "$Revision: 2.125 $"[11:-2].split(".")))
 # $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/doc.py,v $
 
 """
@@ -19,7 +19,7 @@ documentation (both &html; and XSL-FO).
 # import __builtin__ to use property, which is also defined here
 import types, inspect, warnings, __builtin__
 
-from ll.xist import xsc, parsers, sims, errors, xfind
+from ll.xist import xsc, parsers, sims, xfind
 from ll.xist.ns import html, text, docbook, fo, specials, xml
 
 
@@ -324,7 +324,7 @@ class code(inline):
 		return e.convert(converter)
 
 	def convert_html(self, converter):
-		e = converter.target.code(self.content, class_=self.xmlname[True])
+		e = converter.target.code(self.content, class_=self.xmlname)
 		return e.convert(converter)
 
 
@@ -656,37 +656,23 @@ class section(block):
 			context.indentcount += 1
 			text_indent = context.dedent()
 		else:
-			if len(context.sections)>2:
+			if len(context.sections)>1:
 				number = (
-					u".".join(unicode(s) for s in context.sections[1:-1]),
+					u".".join(unicode(s) for s in context.sections[:-1]),
 					u". "
 				)
 			text_indent = None
 
-		if len(context.sections)==2:
-			if context.sections[0]==1:
-				break_before = None
-			else:
-				break_before = u"page"
-			tattrs = fo.block.Attrs(
-				font_family=context.hdfont,
-				color=context.llblue,
-				text_align=u"center",
-				font_size=u"36pt",
-				space_after=u"30pt",
-				break_before=break_before,
-				keep_with_next_within_page=u"always",
-			)
-		else:
-			tattrs = fo.block.Attrs(
-				font_size=p[0],
-				space_before=p[1],
-				space_after=p[2],
-				text_align=u"left",
-				font_family=context.hdfont,
-				keep_with_next_within_page=u"always",
-				text_indent=text_indent
-			)
+		tattrs = fo.block.Attrs(
+			font_size=p[0],
+			color=context.llblue,
+			space_before=p[1],
+			space_after=p[2],
+			text_align=u"left",
+			font_family=context.hdfont,
+			keep_with_next_within_page=u"always",
+			text_indent=text_indent
+		)
 		e = fo.block(
 			fo.block(number, ts, tattrs),
 			cs,
@@ -763,7 +749,7 @@ class item(base):
 	def convert_html(self, converter):
 		context = converter[self]
 		if not context.lists:
-			raise errors.NodeOutsideContextError(self, self.__ns__.list)
+			raise xsc.NodeOutsideContextError(self, self.__ns__.list)
 		if context.lists[-1][0] == "dlist":
 			e = converter.target.dd(self.content)
 		else:
@@ -1197,7 +1183,7 @@ def getdoc(cls, thing):
 
 		# remove this whitespace from every line
 		for i in xrange(len(lines)):
-			if lines[i][:len(startwhite)] == startwhite:
+			if lines[i].startswith(startwhite):
 				lines[i] = lines[i][len(startwhite):]
 
 		# remove empty lines
