@@ -13,7 +13,7 @@
 in <link href="http://www.w3.org/TR/html4/loose.dtd">&html; 4.0 transitional</link>.</par>
 """
 
-__version__ = tuple(map(int, "$Revision: 2.66 $"[11:-2].split(".")))
+__version__ = tuple(map(int, "$Revision: 2.68 $"[11:-2].split(".")))
 # $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/html.py,v $
 
 import cgi # for parse_header
@@ -220,11 +220,10 @@ class meta(xsc.Element):
 					node = self.__class__(
 						self.attrs,
 						http_equiv=u"Content-Type",
-						content=(contenttype, u"; ", u"; ".join("%s=%s" % option for option in options.items()))
+						content=(contenttype, u"; ", u"; ".join(u"%s=%s" % option for option in options.items()))
 					)
-					node.publish(publisher)
-					return
-		super(meta, self).publish(publisher)
+					return node.publish(publisher) # return a generator-iterator
+		return super(meta, self).publish(publisher) # return a generator-iterator
 
 
 class link(xsc.Element):
