@@ -13,7 +13,7 @@
 and classes for the &xml; declaration.</par>
 """
 
-__version__ = tuple(map(int, "$Revision: 2.21 $"[11:-2].split(".")))
+__version__ = tuple(map(int, "$Revision: 2.23 $"[11:-2].split(".")))
 # $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/xml.py,v $
 
 from ll.xist import xsc, utils, sims
@@ -34,9 +34,8 @@ class XML(xsc.ProcInst):
 			node = XML(u"version='%s' encoding='%s'" % (versionfound, publisher.encoding))
 			if standalonefound is not None:
 				node += u" standalone='%s'" % standalonefound
-			node.publish(publisher)
-			return
-		xsc.ProcInst.publish(self, publisher)
+			return node.publish(publisher) # return a generator-iterator
+		return xsc.ProcInst.publish(self, publisher) # return a generator-iterator
 
 
 class XML10(XML):
