@@ -1,8 +1,8 @@
 #! /usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 
-## Copyright 1999-2004 by LivingLogic AG, Bayreuth, Germany.
-## Copyright 1999-2004 by Walter Drwald
+## Copyright 1999-2005 by LivingLogic AG, Bayreuth/Germany.
+## Copyright 1999-2005 by Walter Drwald
 ##
 ## All Rights Reserved
 ##
@@ -28,7 +28,7 @@ from xml.dom import html as htmldtd
 
 from ll import url
 
-import xsc, errors, utils, cssparsers
+import xsc, utils, cssparsers
 from ns import html
 
 
@@ -241,7 +241,7 @@ class SGMLOPParser(sax.xmlreader.XMLReader, sax.xmlreader.Locator):
 			texts = texts[1].split(u";", 1)
 			name = texts[0]
 			if len(texts)==1:
-				raise errors.MalformedCharRefWarning(name)
+				raise xsc.MalformedCharRefWarning(name)
 			if name.startswith(u"#"):
 				try:
 					if name.startswith(u"#x"):
@@ -249,7 +249,7 @@ class SGMLOPParser(sax.xmlreader.XMLReader, sax.xmlreader.Locator):
 					else:
 						node.append(ct(unichr(int(name[1:]))))
 				except ValueError:
-					raise errors.MalformedCharRefWarning(name)
+					raise xsc.MalformedCharRefWarning(name)
 			else:
 				try:
 					c = {"lt": u"<", "gt": u">", "amp": u"&", "quot": u'"', "apos": u"'"}[name]
@@ -277,10 +277,10 @@ class BadEntityParser(SGMLOPParser):
 			name = self._makestring(name)
 			try:
 				self.getContentHandler().skippedEntity(name)
-			except errors.IllegalEntityError:
+			except xsc.IllegalEntityError:
 				try:
 					entity = html.entity(name, xml=True)
-				except errors.IllegalEntityError:
+				except xsc.IllegalEntityError:
 					self.getContentHandler().characters(u"&%s;" % name)
 				else:
 					if issubclass(entity, xsc.CharRef):
@@ -310,7 +310,7 @@ class BadEntityParser(SGMLOPParser):
 			name = texts[0]
 			if len(texts)==1: # no ; found, so it's no entity => append it literally
 				name = u"&" + name
-				warnings.warn(errors.MalformedCharRefWarning(name))
+				warnings.warn(xsc.MalformedCharRefWarning(name))
 				node.append(ct(name))
 				break
 			else:
@@ -322,7 +322,7 @@ class BadEntityParser(SGMLOPParser):
 							node.append(ct(unichr(int(name[1:]))))
 					except (ValueError, OverflowError): # illegal format => append it literally
 						name = u"&%s;" % name
-						warnings.warn(errors.MalformedCharRefWarning(name))
+						warnings.warn(xsc.MalformedCharRefWarning(name))
 						node.append(ct(name))
 				else: # entity reference
 					try:
@@ -330,16 +330,16 @@ class BadEntityParser(SGMLOPParser):
 					except KeyError:
 						try:
 							entity = self.getContentHandler().createEntity(name)
-						except errors.IllegalEntityError:
+						except xsc.IllegalEntityError:
 							try:
 								entity = html.entity(name, xml=True)
 								if issubclass(entity, xsc.CharRef):
 									entity = ct(unichr(entity.codepoint))
 								else:
 									entity = entity()
-							except errors.IllegalEntityError:
+							except xsc.IllegalEntityError:
 								name = u"&%s;" % name
-								warnings.warn(errors.MalformedCharRefWarning(name))
+								warnings.warn(xsc.MalformedCharRefWarning(name))
 								entity = ct(name)
 					else:
 						entity = ct(entity)
@@ -391,7 +391,7 @@ class HTMLParser(BadEntityParser):
 
 		# Check whether this element is allowed in the current context
 		if self._stack and name not in htmldtd.HTML_DTD.get(self._stack[-1], []):
-			warnings.warn(errors.IllegalDTDChildWarning(name, self._stack[-1]))
+			warnings.warn(xsc.IllegalDTDChildWarning(name, self._stack[-1]))
 
 		# Skip unknown attributes (but warn about them)
 		newattrs = {}
@@ -400,7 +400,7 @@ class HTMLParser(BadEntityParser):
 			if attrname=="xmlns" or ":" in attrname or element.Attrs.isallowed(attrname.lower(), xml=True):
 				newattrs[attrname.lower()] = attrvalue
 			else:
-				warnings.warn(errors.IllegalAttrError(element.Attrs, attrname.lower(), xml=True))
+				warnings.warn(xsc.IllegalAttrError(element.Attrs, attrname.lower(), xml=True))
 		BadEntityParser.finish_starttag(self, name, newattrs)
 
 		if name.upper() in htmldtd.HTML_FORBIDDEN_END:
@@ -424,7 +424,7 @@ class HTMLParser(BadEntityParser):
 			BadEntityParser.finish_endtag(self, name)
 			del self._stack[-1]
 		else:
-			warnings.warn(errors.IllegalCloseTagWarning(name))
+			warnings.warn(xsc.IllegalCloseTagWarning(name))
 
 
 class ExpatParser(expatreader.ExpatParser):
@@ -439,7 +439,7 @@ class Parser(object):
 	&sax; events generated by the underlying &sax; parser.</par>
 	"""
 
-	def __init__(self, saxparser=SGMLOPParser, nspool=None, prefixes=None, tidy=False, loc=True, validate=True, encoding="utf-8"):
+	def __init__(self, saxparser=SGMLOPParser, nspool=None, prefixes=None, tidy=False, loc=True, validate=True, encoding=None):
 		"""
 		<par>Create a new <class>Parser</class> instance.</par>
 
@@ -450,14 +450,16 @@ class Parser(object):
 		(all based on Fredrik Lundh's <app>sgmlop</app> from <app moreinfo="http://pyxml.sf.net/">PyXML</app>):</par>
 		<ulist>
 		<item><pyref module="ll.xist.parsers" class="SGMLOPParser"><class>ll.xist.parsers.SGMLOPParser</class></pyref>
-		(which is the default if the <arg>parser</arg> argument is not given);</item>
+		(which is the default if the <arg>saxparser</arg> argument is not given);</item>
 		<item><pyref module="ll.xist.parsers" class="BadEntityParser"><class>ll.xist.parsers.BadEntityParser</class></pyref>
 		(which is based on <class>SGMLOPParser</class> and tries to pass on unknown entity references as literal content);</item>
 		<item><pyref module="ll.xist.parsers" class="HTMLParser"><class>HTMLParser</class></pyref> (which is
 		based on BadEntityParser and tries to make sense of &html; sources).</item>
 		</ulist>
 		</item>
-	
+
+		<term><arg>tidy</arg></term><item>If <arg>tidy</arg> is true, <link href="http://xmlsoft.org/">libxml2</link>'s
+		&html; parser will be used for parsing broken &html;.</item>
 		<term><arg>nspool</arg></term><item>an instance of <pyref module="ll.xist.xsc" class="NSPool"><class>ll.xist.xsc.NSPool</class></pyref>;
 		From this namespace pool namespaces will be taken when the parser
 		encounters <lit>xmlns</lit> attributes.</item>
@@ -472,7 +474,10 @@ class Parser(object):
 
 		<term><arg>validate</arg></term><item>Should the parsed &xml; nodes be validated after parsing?</item>
 
-		<term><arg>encoding</arg></term><item>The default encoding to use, when to source doesn't provide an &xml; header.</item>
+		<term><arg>encoding</arg></term><item>The default encoding to use, when the
+		source doesn't provide an &xml; header. The default <lit>None</lit> results in
+		<lit>"utf-8"</lit> for parsing &xml; and <lit>"iso-8859-1"</lit> when parsing
+		broken &html; (when <lit><arg>tidy</arg></lit> is true).</item>
 		</dlist>
 		"""
 		self.saxparser = saxparser
@@ -494,7 +499,7 @@ class Parser(object):
 	def _last(self):
 		"""
 		return the newest node from the stack that is a real node.
-		(There might be false node on the stack, because we are inside
+		(There might be a fake node on the stack, because we are inside
 		of illegal elements).
 		"""
 		for (node, prefixes) in reversed(self._nesting):
@@ -524,7 +529,7 @@ class Parser(object):
 				name = decode(node.name).lower()
 				try:
 					newnode = ns.element(name, xml=True)()
-				except errors.IllegalElementError:
+				except xsc.IllegalElementError:
 					newnode = xsc.Frag()
 				else:
 					attr = node.properties
@@ -536,7 +541,7 @@ class Parser(object):
 							content = decode(attr.content)
 						try:
 							attrnode = newnode.attrs.set(name, content, xml=True)
-						except errors.IllegalAttrError:
+						except xsc.IllegalAttrError:
 							pass
 						else:
 							attrnode.parsed(self)
@@ -578,8 +583,13 @@ class Parser(object):
 		self.skippingwhitespace = False
 
 		if self.tidy:
+			if encoding is None:
+				encoding = "iso-8859-1"
 			return self._parseHTML(stream, base, sysid, encoding)
 
+		if encoding is None:
+			encoding = "utf-8"
+
 		source = sax.xmlreader.InputSource(sysid)
 		source.setByteStream(stream)
 		source.setEncoding(encoding)
@@ -593,8 +603,8 @@ class Parser(object):
 		#
 		# The parser provides the ability to skip illegal elements, attributes,
 		# processing instructions or entity references, but for illegal elements,
-		# it must still record the new namespaces defined by the illegal element
-		# in this case None is stored in the stack instead of the element node.
+		# it must still record the new namespaces defined by the illegal element.
+		# In this case None is stored in the stack instead of the element node.
 
 		self._nesting = [ (xsc.Frag(), self.prefixes) ]
 		try:
@@ -607,7 +617,7 @@ class Parser(object):
 	def parse(self, stream, base=None, sysid=None):
 		if sysid is None:
 			sysid = base
-		return self._parse(stream, base, self.encoding)
+		return self._parse(stream, base, sysid, self.encoding)
 
 	def parseString(self, string, base=None, sysid=None):
 		if isinstance(string, unicode):
@@ -617,7 +627,7 @@ class Parser(object):
 			encoding = self.encoding
 		stream = cStringIO.StringIO(string)
 		if base is None:
-			base = url.URL("root:STRING")
+			base = url.URL("STRING")
 		if sysid is None:
 			sysid = str(base)
 		return self._parse(stream, base, sysid, encoding)
@@ -629,11 +639,14 @@ class Parser(object):
 			base = stream.finalurl
 		if sysid is None:
 			sysid = str(base)
-		return self._parse(stream, base, sysid, self.encoding)
+		encoding = self.encoding
+		if encoding is None:
+			encoding = stream.encoding
+		return self._parse(stream, base, sysid, encoding)
 
 	def parseFile(self, name, base=None, sysid=None):
 		name = os.path.expanduser(name)
-		stream = open(name, "r")
+		stream = open(name, "rb")
 		if base is None:
 			base = url.File(name)
 		if sysid is None:
@@ -690,7 +703,7 @@ class Parser(object):
 		# We have to check after the old prefix mapping from this element has been dropped
 		element = self.createElement(name) # Unfortunately this creates the element a second time.
 		if element is not None and element.__class__ is not currentelement.__class__:
-			raise errors.ElementNestingError(currentelement.__class__, element.__class__)
+			raise xsc.ElementNestingError(currentelement.__class__, element.__class__)
 		self.skippingwhitespace = False
 
 	def characters(self, content):
@@ -703,7 +716,7 @@ class Parser(object):
 			node.parsed(self)
 			last = self._last()
 			if len(last) and isinstance(last[-1], xsc.Text):
-				node = last[-1] + node.content # join consecutive Text nodes
+				node = last[-1] + unicode(node) # join consecutive Text nodes
 				node.startloc = last[-1].startloc # make sure the replacement node has the original location
 				last[-1] = node # replace it
 			else:
